==> genshitjokes-2023.5.9.tar.gz: genshitjokes-2023.5.9/README.md <==
# 一.索引   Index

<img src="https://github.com/DreamingCats/GenshitJokes/raw/main/readme_img/禁止原批.jpg" width="40%" height="40%"> 

| 索引                                                       |                                                      |                                    |
| ---------------------------------------------------------- | ---------------------------------------------------- | ---------------------------------- |
| [恶意合订本](./genshitjokes/恶意合订本/恶意合订本.md)                   |                                                      |                                    |
| [爆杀原批](./genshitjokes/爆杀原批/爆杀原批.md)                         | [禁原贴吧列表](./genshitjokes/禁原贴吧列表/禁原贴吧列表.md)       | [原批定律](./genshitjokes/原批定律/原批定律.md) |
| [引原丁真](./genshitjokes/引原丁真/引原丁真.md)                         | [原神联动](./genshitjokes/原神联动/原神联动.md)                   |                                    |
| [原批作文选](./genshitjokes/原批作文选.md)                              |                                                      |                                    |
| [3A之战](./genshitjokes/3A之战/3A之战.md)                               | [原批评委](./genshitjokes/原批评委/原批评委.md)                   | [三相之力](./genshitjokes/三相之力/三相之力.md) |
| [超能原批大搜索](./genshitjokes/超能原批大搜索/超能原批大搜索.md)       | [原批眼科病例](./genshitjokes/原批眼科病例/原批眼科病例.md)       |                                    |
| [米孝子](./genshitjokes/米孝子/米孝子.md)                               | [原神使我自豪](./genshitjokes/原神使我自豪/原神使我自豪.md)       |                                    |
| [原批理工科学](./genshitjokes/原批理工科学/原批理工科学.md)             |                                                      |                                    |
| [原批政治经济学](./genshitjokes/原批政治经济学/原批政治经济学.md)       | [原批神兔二相性](./genshitjokes/原批神兔二相性/原批神兔二相性.md) | [原批法学](./genshitjokes/原批法学/原批法学.md) |
| [原批历史与文化学](./genshitjokes/原批历史与文化学/原批历史与文化学.md) | [原批新闻学](./genshitjokes/原批新闻学/原批新闻学.md)             |                                    |
| [策划招聘计划](./genshitjokes/策划招聘计划/策划招聘计划.md)             |                                                      |                                    |



# 二.常见问题   Common Problems

## 1.无法加载图片

图床采用项目本身（Github raw）,如果您能看到markdown中文字，却看不到图片，请使用加速器（[Watt Toolkit](https://steampp.net/)或VPN等）

由于在Android客户端下，使用相对路径的图片不显示，因此使用url绝对路径。

此外，如果需要引用图片，按照以下格式即可：

```
![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/子目录/图片名称.jpg)
```

## 2.下载

因为图片引用采用绝对路径，如果单纯浏览，可以不下载图片，只下载markdown文件即可。

### 1.release
选最新的下载即可，更新慢
[releases](https://github.com/DreamingCats/GenshitJokes/releases)

### 2.直接下载（推荐）
![](https://github.com/DreamingCats/GenshitJokes/raw/main/images/download.png)

或使用Git：

```
git clone https://github.com/DreamingCats/GenshitJokes.git
```

### 3.pip

需要安装Python

[GenshitJokes·PyPI](https://pypi.org/project/genshitjokes/#description)

```
pip install genshitjokes
```

### 4.docker
[laosepi/genshitjokes - Docker Image | Docker Hub](https://hub.docker.com/r/laosepi/genshitjokes)

```
docker pull laosepi/genshitjokes
```

## 3.投稿

见[投稿说明](./CONTRIBUTING.md)

## 4.联系删除

如果某位用户并不想被挂，可以联系我，我会再下一次更新中删除对应的内容。


# 三.简介 A brief introduction

本项目的其他名称：
原批笑话 Genshit Jokes
原批圣经 Genshit Bible
原氏物语 The Tale of Genshit

原批笑话和鸡3笑话收集，采用Markdown语法编写，排名不分先后，不定期更新

欢迎星星和叉子

收集于网络，欢迎转载，如有侵权可联系删除

图片内容仅做收集，并不代表本人@DreamingCats的观点和立场。

有些图片画质不如原神，也很难保证不是反串，或者PS/F12，看个乐呵就行

最后，搞这个合集的目的之一也是想告诉大家：<font color="red">互联网有历史</font>

![](https://github.com/DreamingCats/GenshitJokes/raw/main/readme_img/一定是米哈游干的.gif)

### 什么是原批？  Who is a genshit?

<a href="https://jikipedia.com/definition/baidu_qa/458907976" target="_blank">原批-小鸡词典</a>

国外一般将这类行为叫做Genshit。

### 在哪里可以看到原批？ Where can find genshits?

几乎在互联网的任何地方。

<a href="https://space.bilibili.com/3196602" target="_blank">B站原神官号</a>

<a href="https://bbs.mihoyo.com/ys/" target="_blank">原神社区-米游社（鸡舍）</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8E%9F%E7%A5%9E&ie=utf-8&tab=main" target="_blank">百度原神吧</a>

<a href="" target="_blank"></a>

### 收集来源  Source

#### ①百度
<a href="https://tieba.baidu.com/f?ie=utf-8&kw=mihoyo&fr=search" target="_blank">mihoyo吧</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8E%9F%E6%89%B9%E7%AC%91%E8%AF%9D&ie=utf-8" target="_blank">原批笑话吧</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8F%8D%E5%8E%9F%E7%A5%9E&ie=utf-8&pn=50" target="_blank">反原神吧</a>

#### ②B站

<a href="https://space.bilibili.com/1443474511/dynamic" target="_blank">吟原詩人</a>

<a href="https://space.bilibili.com/3196602/dynamic" target="_blank">原神玩家集體记忆名錄</a>

# 四.画饼

## 1.原批数据集

NLP监督学习

## 2.自动收集

# 五.后记

正确的，直接的，中肯的，完整的，
立体的，客观的，合理的，明晰的，
真实的，辩证的，深刻的，通达的，
优美的，巧妙的，精辟的，雅致的，
机智的，全面的，
形而上学的，脚踏实地的，实事求是的，经世致用的，雅俗共赏的，
明白晓畅的，针砭时弊的，不偏不倚的，恰如其分的，滴水不漏的，
不容质疑的，切中要害的，一针见血的，淋漓尽致的，深谙事理的，
真知灼见的，振聋发聩的，微言大义的，金声玉振的，
透过现象看本质的，知其然而知其所以然的，可供世人仿效的，千古颠扑不破的

重要的、紧迫的、自觉的、主动的、坚定的、
全局的、前瞻的、积极的、创造的、长期的、
复杂的、艰巨的、敏锐的、有效的、法制的、
规范的、持续的、集约的、正常的、有序的、
智能的、优质的、科学的、年轻的、专业的、
信息的、数字的、标准的、精细的

# 六.Star History

[![Star History Chart](https://api.star-history.com/svg?repos=DreamingCats/GenshitJokes&type=Date)](https://star-history.com/#DreamingCats/GenshitJokes&Date)

==> genshitjokes-2023.5.26.tar.gz: genshitjokes-2023.5.26/README.md <==
# 一.索引   Index

<img src="https://github.com/DreamingCats/GenshitJokes/raw/main/readme_img/禁止原批.jpg" width="40%" height="40%"> 

| 索引                                                       |                                                      |                                    |
| ---------------------------------------------------------- | ---------------------------------------------------- | ---------------------------------- |
| [恶意合订本](./genshitjokes/恶意合订本/恶意合订本.md)                   |                                                      |                                    |
| [爆杀原批](./genshitjokes/爆杀原批/爆杀原批.md)                         | [禁原贴吧列表](./genshitjokes/禁原贴吧列表/禁原贴吧列表.md)       | [原批定律](./genshitjokes/原批定律/原批定律.md) |
| [引原丁真](./genshitjokes/引原丁真/引原丁真.md)                         | [原神联动](./genshitjokes/原神联动/原神联动.md)                   |                                    |
| [原批作文选](./genshitjokes/原批作文选.md)                              |                                                      |                                    |
| [3A之战](./genshitjokes/3A之战/3A之战.md)                               | [原批评委](./genshitjokes/原批评委/原批评委.md)                   | [三相之力](./genshitjokes/三相之力/三相之力.md) |
| [超能原批大搜索](./genshitjokes/超能原批大搜索/超能原批大搜索.md)       | [原批眼科病例](./genshitjokes/原批眼科病例/原批眼科病例.md)       |                                    |
| [米孝子](./genshitjokes/米孝子/米孝子.md)                               | [原神使我自豪](./genshitjokes/原神使我自豪/原神使我自豪.md)       |                                    |
| [原批理工科学](./genshitjokes/原批理工科学/原批理工科学.md)             |                                                      |                                    |
| [原批政治经济学](./genshitjokes/原批政治经济学/原批政治经济学.md)       | [原批神兔二相性](./genshitjokes/原批神兔二相性/原批神兔二相性.md) | [原批法学](./genshitjokes/原批法学/原批法学.md) |
| [原批历史与文化学](./genshitjokes/原批历史与文化学/原批历史与文化学.md) | [原批新闻学](./genshitjokes/原批新闻学/原批新闻学.md)             |                                    |
| [原批策划](./genshitjokes/原批策划/原批策划.md)     |                                                      |                                    |



# 二.常见问题   Common Problems

## 1.无法加载图片

图床采用项目本身（Github raw）,如果您能看到markdown中文字，却看不到图片，请使用加速器（[Watt Toolkit](https://steampp.net/)或VPN等）

由于在Android客户端下，使用相对路径的图片不显示，因此使用url绝对路径。

此外，如果需要引用图片，按照以下格式即可：

```
![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/子目录/图片名称.jpg)
```

## 2.下载

因为图片引用采用绝对路径，如果单纯浏览，可以不下载图片，只下载markdown文件即可。

### 1.release
选最新的下载即可，更新慢
[releases](https://github.com/DreamingCats/GenshitJokes/releases)

### 2.直接下载（推荐）
![](https://github.com/DreamingCats/GenshitJokes/raw/main/images/download.png)

或使用Git：

```
git clone https://github.com/DreamingCats/GenshitJokes.git
```

### 3.pip

需要安装Python

[GenshitJokes·PyPI](https://pypi.org/project/genshitjokes/#description)

```
pip install genshitjokes
```

### 4.docker
[laosepi/genshitjokes - Docker Image | Docker Hub](https://hub.docker.com/r/laosepi/genshitjokes)

```
docker pull laosepi/genshitjokes
```

## 3.投稿

见[投稿说明](./CONTRIBUTING.md)

## 4.联系删除

如果某位用户并不想被挂，可以联系我，我会再下一次更新中删除对应的内容。


# 三.简介 A brief introduction

本项目的其他名称：
原批笑话 Genshit Jokes
原批圣经 Genshit Bible
原氏物语 The Tale of Genshit

原批笑话和鸡3笑话收集，采用Markdown语法编写，排名不分先后，不定期更新

欢迎星星和叉子

收集于网络，欢迎转载，如有侵权可联系删除

图片内容仅做收集，并不代表本人@DreamingCats的观点和立场。

有些图片画质不如原神，也很难保证不是反串，或者PS/F12，看个乐呵就行

最后，搞这个合集的目的之一也是想告诉大家：<font color="red">互联网有历史</font>

![](https://github.com/DreamingCats/GenshitJokes/raw/main/readme_img/一定是米哈游干的.gif)

### 什么是原批？  Who is a genshit?

<a href="https://jikipedia.com/definition/baidu_qa/458907976" target="_blank">原批-小鸡词典</a>

国外一般将这类行为叫做Genshit。

### 在哪里可以看到原批？ Where can find genshits?

几乎在互联网的任何地方。

<a href="https://space.bilibili.com/3196602" target="_blank">B站原神官号</a>

<a href="https://bbs.mihoyo.com/ys/" target="_blank">原神社区-米游社（鸡舍）</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8E%9F%E7%A5%9E&ie=utf-8&tab=main" target="_blank">百度原神吧</a>

<a href="" target="_blank"></a>

### 收集来源  Source

#### ①百度
<a href="https://tieba.baidu.com/f?ie=utf-8&kw=mihoyo&fr=search" target="_blank">mihoyo吧</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8E%9F%E6%89%B9%E7%AC%91%E8%AF%9D&ie=utf-8" target="_blank">原批笑话吧</a>

<a href="https://tieba.baidu.com/f?kw=%E5%8F%8D%E5%8E%9F%E7%A5%9E&ie=utf-8&pn=50" target="_blank">反原神吧</a>

#### ②B站

<a href="https://space.bilibili.com/1443474511/dynamic" target="_blank">吟原詩人</a>

<a href="https://space.bilibili.com/3196602/dynamic" target="_blank">原神玩家集體记忆名錄</a>

# 四.画饼

## 1.原批数据集

NLP监督学习

## 2.自动收集

# 五.后记

玩原神玩的，

正确的，直接的，中肯的，完整的，
立体的，客观的，合理的，明晰的，
真实的，辩证的，深刻的，通达的，
优美的，巧妙的，精辟的，雅致的，
机智的，全面的，
形而上学的，脚踏实地的，实事求是的，经世致用的，雅俗共赏的，
明白晓畅的，针砭时弊的，不偏不倚的，恰如其分的，滴水不漏的，
不容质疑的，切中要害的，一针见血的，淋漓尽致的，深谙事理的，
真知灼见的，振聋发聩的，微言大义的，金声玉振的，
透过现象看本质的，知其然而知其所以然的，可供世人仿效的，千古颠扑不破的，
重要的、紧迫的、自觉的、主动的、坚定的、
全局的、前瞻的、积极的、创造的、长期的、
复杂的、艰巨的、敏锐的、有效的、法制的、
规范的、持续的、集约的、正常的、有序的、
智能的、优质的、科学的、年轻的、专业的、
信息的、数字的、标准的、精细的...

# 六.Star History

[![Star History Chart](https://api.star-history.com/svg?repos=DreamingCats/GenshitJokes&type=Date)](https://star-history.com/#DreamingCats/GenshitJokes&Date)
